@@ -136,7 +136,7 @@ html_context = {
            # 'https://media.readthedocs.org/css/sphinx_rtd_theme.css',
            # 'https://media.readthedocs.org/css/readthedocs-doc-embed.css',
            # '_static/jssor.css',
-           '_static/tango_cs_theme.css',
+           '_static/css/tango_cs_theme.css',
         ],
     }
 
@@ -253,8 +253,8 @@ rst_epilog = """\
 .. _asyncio: https://asyncio.readthedocs.io/en/latest/
 .. _boost-python: http://www.boost.org/libs/python
 .. _PyPi: https://pypi.python.org/pypi/pytango
-.. _issues: https://github.com/tango-controls/pytango/issues
-.. _PRs: https://github.com/tango-controls/pytango/pulls
+.. _issues: https://gitlab.com/tango-controls/pytango/issues
+.. _PRs: https://gitlab.com/tango-controls/pytango/-/merge_requests
 
 """
 
@@ -266,8 +266,8 @@ intersphinx_mapping = {
     'http://docs.scipy.org/doc/numpy': None,
     'http://ipython.org/ipython-doc/stable': None,
     'http://api.mongodb.org/python/current': None,
-    'http://packages.python.org/CouchDB': None,
-    'http://pycassa.github.com/pycassa': None,
+    'http://couchdb-python.readthedocs.io/en/latest': None,
+    'http://pycassa.github.io/pycassa': None,
     'http://docs.sqlalchemy.org/en/latest': None,
 }
 
