@@ -1,15 +1,11 @@
 import time
-from PyTango.server import run
-from PyTango.server import Device, DeviceMeta
-from PyTango.server import attribute, command   
+from PyTango.server import Device, attribute, command
 
 
 class Clock(Device):
-    __metaclass__ = DeviceMeta
 
     @attribute
     def time(self):
-	"""The time attribute"""
         return time.time()
 
     @command(dtype_in=str, dtype_out=str)
@@ -18,4 +14,4 @@ class Clock(Device):
 
 
 if __name__ == "__main__":
-    run([Clock])
+    Clock.run_server()
