@@ -17,8 +17,7 @@ extern const char *param_must_be_seq;
 extern const char *unreachable_code;
 extern const char *non_string_seq;
 
-const char *param_numb_or_str_numb = "Second parameter must be an int or a "
-                                     "string representing an int";
+const char *param_numb_or_str_numb = "Second parameter must be an int or a string representing an int";
 
 struct PyDatabase
 {
@@ -36,12 +35,13 @@ struct PyDatabase
                 return bopy::make_tuple();
         }
     };
-    
+
     static inline boost::shared_ptr<Tango::Database>
     makeDatabase_host_port1(const std::string &host, int port)
     {
-        return boost::shared_ptr<Tango::Database>
-            (new Tango::Database(const_cast<std::string&>(host), port));
+        AutoPythonAllowThreads guard;
+        return boost::shared_ptr<Tango::Database>(new Tango::Database(const_cast<std::string&>(host), port),
+                                                  DeleterWithoutGIL());
     }
 
     static inline boost::shared_ptr<Tango::Database>
@@ -53,15 +53,17 @@ struct PyDatabase
         {
             raise_(PyExc_TypeError, param_numb_or_str_numb);
         }
-        return boost::shared_ptr<Tango::Database>
-            (new Tango::Database(const_cast<std::string&>(host), port));
+        AutoPythonAllowThreads guard;
+        return boost::shared_ptr<Tango::Database>(new Tango::Database(const_cast<std::string&>(host), port),
+                                                  DeleterWithoutGIL());
     }
 
     static inline boost::shared_ptr<Tango::Database>
     makeDatabase_file(const std::string &filename)
     {
-        return boost::shared_ptr<Tango::Database>
-            (new Tango::Database(const_cast<std::string&>(filename)));
+        AutoPythonAllowThreads guard;
+        return boost::shared_ptr<Tango::Database>(new Tango::Database(const_cast<std::string&>(filename)),
+                                                  DeleterWithoutGIL());
     }
 
     static inline boost::python::str
@@ -121,7 +123,7 @@ struct PyDatabase
         self.get_device_from_alias(input, output);
         return boost::python::str(output);
     }
-    
+
     static inline boost::python::str
     get_alias_from_device(Tango::Database& self, const std::string &input)
     {
@@ -129,7 +131,7 @@ struct PyDatabase
         self.get_alias_from_device(input, output);
         return boost::python::str(output);
     }
-    
+
     static inline boost::python::str
     get_attribute_from_alias(Tango::Database& self, const std::string &input)
     {
@@ -137,7 +139,7 @@ struct PyDatabase
         self.get_attribute_from_alias(input, output);
         return boost::python::str(output);
     }
-    
+
     static inline boost::python::str
     get_alias_from_attribute(Tango::Database& self, const std::string &input)
     {
@@ -217,6 +219,8 @@ void export_database()
         &Tango::Database::get_device_property_list;
     Tango::DbHistoryList (Tango::Database::*get_device_attribute_property_history_)(std::string &, std::string &, std::string &) =
         &Tango::Database::get_device_attribute_property_history;
+    Tango::DbHistoryList (Tango::Database::*get_device_pipe_property_history_)(std::string &, std::string &, std::string &) =
+        &Tango::Database::get_device_pipe_property_history;
     Tango::DbHistoryList (Tango::Database::*get_class_property_history_)(std::string &, std::string &) =
         &Tango::Database::get_class_property_history;
     Tango::DbDatum (Tango::Database::*get_class_list_)(std::string &) =
@@ -225,6 +229,8 @@ void export_database()
         &Tango::Database::get_class_property_list;
     Tango::DbHistoryList (Tango::Database::*get_class_attribute_property_history_)(std::string &, std::string &, std::string &) =
         &Tango::Database::get_class_attribute_property_history;
+    Tango::DbHistoryList (Tango::Database::*get_class_pipe_property_history_)(std::string &, std::string &, std::string &) =
+        &Tango::Database::get_class_pipe_property_history;
     Tango::DbDatum (Tango::Database::*get_class_attribute_list_)(std::string &, std::string &) =
         &Tango::Database::get_class_attribute_list;
 
@@ -232,14 +238,14 @@ void export_database()
         &Tango::Database::import_device;
     Tango::DbDevFullInfo (Tango::Database::*get_device_info_)(std::string &) =
         &Tango::Database::get_device_info;
-    
+
     Tango::DbDatum (Tango::Database::*get_attribute_alias_list_)(std::string &) =
         &Tango::Database::get_attribute_alias_list;
     void (Tango::Database::*put_attribute_alias_)(std::string &, std::string &) =
         &Tango::Database::put_attribute_alias;
     void (Tango::Database::*delete_attribute_alias_)(std::string &) =
         &Tango::Database::delete_attribute_alias;
-    
+
     bopy::class_<Tango::Database, bopy::bases<Tango::Connection> > Database("Database", bopy::init<>())
     ;
 
@@ -253,7 +259,7 @@ void export_database()
         // Pickle
         //
         .def_pickle(PyDatabase::PickleSuite())
-        
+
         //
         // general methods
         //
@@ -273,7 +279,7 @@ void export_database()
         .def("is_multi_tango_host", &Tango::Database::is_multi_tango_host)
         .def("get_file_name", &Tango::Database::get_file_name,
             bopy::return_value_policy<bopy::copy_const_reference>())
-            
+
         //
         // General methods
         //
@@ -304,28 +310,28 @@ void export_database()
 
         .def("add_device", &Tango::Database::add_device)
         .def("delete_device", &Tango::Database::delete_device)
-        .def("import_device", 
+        .def("import_device",
             (Tango::DbDevImportInfo (Tango::Database::*) (const std::string &))
             import_device_)
         .def("export_device", &Tango::Database::export_device)
         .def("unexport_device", &Tango::Database::unexport_device)
-        .def("get_device_info", 
+        .def("get_device_info",
             (Tango::DbDevFullInfo (Tango::Database::*) (const std::string &))
             get_device_info_)
         .def("get_device_name",
-            (Tango::DbDatum (Tango::Database::*) (const string &, const string &))
+            (Tango::DbDatum (Tango::Database::*) (const std::string &, const std::string &))
             get_device_name_)
         .def("get_device_exported",
-            (Tango::DbDatum (Tango::Database::*) (const string &))
+            (Tango::DbDatum (Tango::Database::*) (const std::string &))
             get_device_exported_)
         .def("get_device_domain",
-            (Tango::DbDatum (Tango::Database::*) (const string &))
+            (Tango::DbDatum (Tango::Database::*) (const std::string &))
             get_device_domain_)
         .def("get_device_family",
-            (Tango::DbDatum (Tango::Database::*) (const string &))
+            (Tango::DbDatum (Tango::Database::*) (const std::string &))
             get_device_family_)
         .def("get_device_member",
-            (Tango::DbDatum (Tango::Database::*) (const string &))
+            (Tango::DbDatum (Tango::Database::*) (const std::string &))
             get_device_member_)
         .def("get_device_alias", &PyDatabase::get_device_alias)
         .def("get_alias", &PyDatabase::get_alias)
@@ -347,7 +353,7 @@ void export_database()
         .def("delete_device_alias",
             (void (Tango::Database::*) (const std::string &))
             delete_device_alias_)
-        
+
         //
         // server methods
         //
@@ -392,7 +398,7 @@ void export_database()
             (Tango::DbDatum (Tango::Database::*) (const std::string &))
             get_device_class_list_)
         .def("get_server_release", &Tango::Database::get_server_release)
-        
+
         //
         // property methods
         //
@@ -427,13 +433,29 @@ void export_database()
         .def("_get_device_attribute_property",
             (void (Tango::Database::*) (std::string, Tango::DbData &))
             &Tango::Database::get_device_attribute_property)
+        .def("_get_device_pipe_property",
+            (void (Tango::Database::*) (std::string, Tango::DbData &))
+            &Tango::Database::get_device_pipe_property)
         .def("_put_device_attribute_property",
             &Tango::Database::put_device_attribute_property)
+        .def("_put_device_pipe_property",
+            &Tango::Database::put_device_pipe_property)
         .def("_delete_device_attribute_property",
             &Tango::Database::delete_device_attribute_property)
+        .def("_delete_device_pipe_property",
+            &Tango::Database::delete_device_pipe_property)
         .def("get_device_attribute_property_history",
             (Tango::DbHistoryList (Tango::Database::*) (const std::string &, const std::string &, const std::string &))
             get_device_attribute_property_history_)
+        .def("get_device_pipe_property_history",
+            (Tango::DbHistoryList (Tango::Database::*) (const std::string &, const std::string &, const std::string &))
+            get_device_pipe_property_history_)
+        .def("get_device_attribute_list",
+            (void (Tango::Database::*) (const std::string &, StdStringVector &))
+            &Tango::Database::get_device_attribute_list)
+        .def("get_device_pipe_list",
+            (void (Tango::Database::*) (const std::string &, StdStringVector &))
+            &Tango::Database::get_device_pipe_list)
         .def("_get_class_property",
             (void (Tango::Database::*) (std::string, Tango::DbData &))
             &Tango::Database::get_class_property)
@@ -451,17 +473,28 @@ void export_database()
         .def("_get_class_attribute_property",
             (void (Tango::Database::*) (std::string, Tango::DbData &))
             &Tango::Database::get_class_attribute_property)
+        .def("_get_class_pipe_property",
+            (void (Tango::Database::*) (std::string, Tango::DbData &))
+            &Tango::Database::get_class_pipe_property)
         .def("_put_class_attribute_property",
             &Tango::Database::put_class_attribute_property)
+        .def("_put_class_pipe_property",
+            &Tango::Database::put_class_pipe_property)
         .def("_delete_class_attribute_property",
             &Tango::Database::delete_class_attribute_property)
+        .def("_delete_class_pipe_property",
+            &Tango::Database::delete_class_pipe_property)
         .def("get_class_attribute_property_history",
             (Tango::DbHistoryList (Tango::Database::*) (const std::string &, const std::string &, const std::string &))
             get_class_attribute_property_history_)
+        .def("get_class_pipe_property_history",
+            (Tango::DbHistoryList (Tango::Database::*) (const std::string &, const std::string &, const std::string &))
+            get_class_pipe_property_history_)
 
         .def("get_class_attribute_list",
             (Tango::DbDatum (Tango::Database::*) (const std::string &, const std::string &))
             get_class_attribute_list_)
+        .def("get_class_pipe_list", &Tango::Database::get_class_pipe_list)
 
         //
         // Attribute methods
@@ -487,7 +520,9 @@ void export_database()
             (void (Tango::Database::*) (const std::string &))
             &Tango::Database::unexport_event)
 
-// alias methods
+        //
+        // alias methods
+        //
 
         .def("get_device_from_alias", &PyDatabase::get_device_from_alias)
         .def("get_alias_from_device", &PyDatabase::get_alias_from_device)
@@ -496,4 +531,3 @@ void export_database()
 
         ;
 }
-
