@@ -96,13 +96,17 @@ char* from_str_to_char(PyObject* in)
 	out = strncpy(out, PyBytes_AsString(bytes_in), size);
         Py_DECREF(bytes_in);
     }
-    else
+    else if (PyBytes_Check(in))
     {
 	Py_ssize_t size = PyBytes_Size(in);
 	out = new char[size+1];
 	out[size] = '\0';
 	out = strncpy(out, PyBytes_AsString(in), size);
     }
+    else
+    {
+        raise_(PyExc_TypeError, "can't translate python object to C char*");
+    }
     return out;
 }
 
@@ -220,3 +224,13 @@ bool hasattr(boost::python::object& obj, const std::string& name)
 {
     return PyObject_HasAttrString(obj.ptr(), name.c_str());
 }
+
+void export_ensure_omni_thread()
+{
+  bopy::class_<EnsureOmniThread, boost::noncopyable>(
+    "EnsureOmniThread", bopy::init<>())
+    .def("_acquire", &EnsureOmniThread::acquire)
+    .def("_release", &EnsureOmniThread::release)
+  ;
+  bopy::def("is_omni_thread", is_omni_thread);
+}
