@@ -69,7 +69,7 @@ void allocate_any(CORBA::Any *&any_ptr)
     {
         any_ptr = new CORBA::Any();
     }
-    catch (bad_alloc)
+    catch (std::bad_alloc&)
     {
         Tango::Except::throw_exception(
             "API_MemoryAllocation",
@@ -83,7 +83,7 @@ void throw_bad_type(const char *type)
     TangoSys_OMemStream o;
 
     o << "Incompatible command argument type, expected type is : Tango::" 
-      << type << ends;
+      << type << std::ends;
     Tango::Except::throw_exception(
             "API_IncompatibleCmdArgumentType",
             o.str(),
@@ -108,10 +108,14 @@ void insert_scalar<Tango::DEV_STRING>(boost::python::object &o, CORBA::Any &any)
 	any <<= PyBytes_AsString(bytes_o_ptr);
         Py_DECREF(bytes_o_ptr);
     }
-    else
+    else if (PyBytes_Check(o_ptr))
     {
         any <<= PyBytes_AsString(o_ptr);
     }
+    else
+    {
+        raise_(PyExc_TypeError, "can't translate python object to C char*");
+    }
 }
 
 template<>
@@ -220,11 +224,17 @@ void extract_scalar<Tango::DEV_ENCODED>(const CORBA::Any &any, boost::python::ob
 
     if ((any >>= data) == false)
         throw_bad_type(Tango::CmdArgTypeName[Tango::DEV_ENCODED]);
-    
-    bopy::str encoded_format(data[0].encoded_format);
-    bopy::str encoded_data((const char*)data[0].encoded_data.get_buffer(),
-                           data[0].encoded_data.length());
-    
+
+    boost::python::str encoded_format(data[0].encoded_format);
+    boost::python::object encoded_data(
+        boost::python::handle<>(
+            PyBytes_FromStringAndSize(
+                (const char*)data[0].encoded_data.get_buffer(),
+                data[0].encoded_data.length()
+            )
+        )
+    );
+
     o = boost::python::make_tuple(encoded_format, encoded_data);
 }
 
