@@ -1474,7 +1474,7 @@ void export_device_impl()
     
     class_<Tango::DeviceImpl, std::auto_ptr<DeviceImplWrap>, boost::noncopyable>("DeviceImpl",
         init<CppDeviceClass *, const char *,
-             optional<const char *, Tango::DevState, const char *> >())
+             boost::python::optional<const char *, Tango::DevState, const char *> >())
 
         .def("init_device", pure_virtual(&Tango::DeviceImpl::init_device))
         .def("set_state", &Tango::DeviceImpl::set_state)
@@ -1504,6 +1504,7 @@ void export_device_impl()
         .def("set_archive_event",
             &Tango::DeviceImpl::set_archive_event,
             set_archive_event_overload())
+        .def("set_data_ready_event", &Tango::DeviceImpl::set_data_ready_event)
         .def("_add_attribute", &PyDeviceImpl::add_attribute)
         .def("_remove_attribute", &PyDeviceImpl::remove_attribute,
             remove_attribute_overload())
@@ -1719,7 +1720,7 @@ void export_device_impl()
            boost::noncopyable>
            ("Device_2Impl",
             init<CppDeviceClass *, const char *,
-                 optional<const char *, Tango::DevState, const char *> >())
+                 boost::python::optional<const char *, Tango::DevState, const char *> >())
         .def("get_attribute_config_2", &PyDevice_2Impl::get_attribute_config_2)
         //@TODO .def("read_attribute_history_2", &PyDevice_2Impl::read_attribute_history_2)
     ;
@@ -1729,7 +1730,7 @@ void export_device_impl()
            boost::noncopyable>
            ("Device_3Impl",
             init<CppDeviceClass *, const char *,
-                 optional<const char *, Tango::DevState, const char *> >())
+                 boost::python::optional<const char *, Tango::DevState, const char *> >())
         .def("init_device", pure_virtual(&Tango::Device_3Impl::init_device))
         .def("delete_device", &Tango::Device_3Impl::delete_device,
             &Device_3ImplWrap::default_delete_device)
@@ -1754,7 +1755,7 @@ void export_device_impl()
            boost::noncopyable>
            ("Device_4Impl",
             init<CppDeviceClass *, const char *,
-                 optional<const char *, Tango::DevState, const char *> >())
+                 boost::python::optional<const char *, Tango::DevState, const char *> >())
         .def("init_device", pure_virtual(&Tango::Device_4Impl::init_device))
         .def("delete_device", &Tango::Device_4Impl::delete_device,
             &Device_4ImplWrap::default_delete_device)
@@ -1778,7 +1779,7 @@ void export_device_impl()
            boost::noncopyable>
            ("Device_5Impl",
             init<CppDeviceClass *, const char *,
-                 optional<const char *, Tango::DevState, const char *> >())
+                 boost::python::optional<const char *, Tango::DevState, const char *> >())
         .def("init_device", pure_virtual(&Tango::Device_5Impl::init_device))
         .def("delete_device", &Tango::Device_5Impl::delete_device,
             &Device_5ImplWrap::default_delete_device)
@@ -1813,7 +1814,7 @@ void export_device_impl()
 //{
 //    class_<Tango::DeviceIntrThread, boost::noncopyable>("DeviceImpl",
 //        init<CppDeviceClass *, const char *,
-//             optional<const char *, Tango::DevState, const char *> >())
+//             boost::python::optional<const char *, Tango::DevState, const char *> >())
 //
 //    .def("push_event",
 //        (void (*) (Tango::DevIntrThread &))
