@@ -110,7 +110,7 @@ namespace PyTango { namespace Pipe {
 					     const char *method)
     {
 	TangoSys_OMemStream o;
-	o << "Wrong Python type for pipe " << name << ends;
+	o << "Wrong Python type for pipe " << name << std::ends;
 	Tango::Except::throw_exception("PyDs_WrongPythonDataTypeForPipe",
 				       o.str(), method);
     }
@@ -385,13 +385,13 @@ namespace PyTango { namespace Pipe {
         // the Tango C++ API doesnt't provide a way to do it
         Py_ssize_t size = bopy::len(py_value);
 	std::vector<std::string> elem_names;
-	for(ssize_t i = 0; i < size; ++i)
+	for(Py_ssize_t i = 0; i < size; ++i)
 	{
 	    elem_names.push_back(bopy::extract<std::string>(py_value[i]["name"]));
 	}
 	obj.set_data_elt_names(elem_names);
 
-	for(ssize_t i = 0; i < size; ++i)
+	for(Py_ssize_t i = 0; i < size; ++i)
 	{
             bopy::object item = py_value[i];
             std::string item_name = bopy::extract<std::string>(item["name"]);
@@ -469,7 +469,7 @@ namespace PyDevicePipe
 {
 	static void throw_wrong_python_data_type(const std::string &name, const char *method) {
 		TangoSys_OMemStream o;
-		o << "Wrong Python type for pipe " << name << ends;
+		o << "Wrong Python type for pipe " << name << std::ends;
 		Tango::Except::throw_exception("PyDs_WrongPythonDataTypeForPipe",
 				o.str(), method);
 	}
@@ -507,7 +507,7 @@ namespace PyDevicePipe
 	}
 
 	void __append(Tango::DevicePipeBlob& dpb, const std::string& name, bopy::object& value) {
-		if (__check_type<string>(value)) {
+		if (__check_type<std::string>(value)) {
 			__append_scalar<Tango::DevicePipeBlob, Tango::DEV_STRING>(dpb, name, value);
 		} else if (__check_type<int>(value)) {
 			__append_scalar<Tango::DevicePipeBlob, Tango::DEV_LONG64>(dpb, name, value);
@@ -516,7 +516,7 @@ namespace PyDevicePipe
 		} else if (__check_type<bool>(value)) {
 			__append_scalar<Tango::DevicePipeBlob, Tango::DEV_BOOLEAN>(dpb, name, value);
 		} else if (__check_type<bopy::list>(value)) {
-			if (__check_type<string>(value[0])) {
+			if (__check_type<std::string>(value[0])) {
 				__append_array<Tango::DevicePipeBlob, Tango::DEVVAR_STRINGARRAY>(dpb, name, value);
 			} else if (__check_type<int>(value[0])) {
 				__append_array<Tango::DevicePipeBlob, Tango::DEVVAR_LONG64ARRAY>(dpb, name, value);
@@ -533,13 +533,13 @@ namespace PyDevicePipe
 	void __set_value(Tango::DevicePipeBlob& dpb, bopy::dict& dict) {
 		int nitems = len(dict);
 		std::vector<std::string> elem_names;
-		for (auto i=0; i<nitems; i++) {
+		for (int i=0; i<nitems; i++) {
 			elem_names.push_back(bopy::extract<std::string>(dict.keys()[i]));
 		}
 		dpb.set_data_elt_names(elem_names);
 
 		bopy::list values = dict.values();
-		for (auto i=0; i <nitems; ++i) {
+		for (int i=0; i <nitems; ++i) {
 			bopy::object item = values[i];
 			// Check if the value is an inner blob
 			bopy::tuple ptuple;
