@@ -22,6 +22,9 @@ import six
 import types
 import numbers
 import enum
+
+from argparse import HelpFormatter
+
 try:
     import collections.abc as collections_abc  # python 3.3+
 except ImportError:
@@ -30,7 +33,7 @@ except ImportError:
 from ._tango import StdStringVector, StdDoubleVector, \
     DbData, DbDatum, DbDevInfos, DbDevExportInfos, CmdArgType, AttrDataFormat, \
     EventData, AttrConfEventData, DataReadyEventData, DevFailed, constants, \
-    DevState, CommunicationFailed, PipeEventData, DevIntrChangeEventData
+    DevState, CommunicationFailed, PipeEventData, DevIntrChangeEventData, Database
 
 from . import _tango
 from .constants import AlrmValueNotSpec, StatusNotSet, TgLibVers
@@ -47,7 +50,7 @@ __all__ = (
     "CaselessList", "CaselessDict", "EventCallBack", "get_home",
     "from_version_str_to_hex_str", "from_version_str_to_int",
     "seq_2_StdStringVector", "StdStringVector_2_seq",
-    "dir2", "TO_TANGO_TYPE")
+    "dir2", "TO_TANGO_TYPE", "ensure_binary")
 
 __docformat__ = "restructuredtext"
 
@@ -178,7 +181,7 @@ def __build_to_tango_type():
             CmdArgType.DevULong: numpy.uint32,
             CmdArgType.DevLong64: numpy.int64,
             CmdArgType.DevULong64: numpy.uint64,
-            CmdArgType.DevString: numpy.str,
+            CmdArgType.DevString: str,
             CmdArgType.DevDouble: numpy.float64,
             CmdArgType.DevFloat: numpy.float32,
         }
@@ -1070,7 +1073,7 @@ def obj_2_property(value):
             else:
                 if not is_pure_str(v):
                     v = str(v)
-                v = six.ensure_binary(v, encoding='latin-1')
+                v = ensure_binary(v, encoding='latin-1')
                 db_datum.value_string.append(v)
             new_value.append(db_datum)
         value = new_value
@@ -1693,7 +1696,6 @@ PyTango runtime is:
     Python : {2.PY_VERSION}
     Numpy  : {2.NUMPY_VERSION}
     Tango  : {2.TANGO_VERSION}
-    Boost  : {2.BOOST_VERSION}
 
 PyTango running on:
 {2.UNAME}
@@ -1737,3 +1739,47 @@ def dir2(obj):
         attrs.update(dir2(cls))
     attrs.update(get_attrs(obj))
     return list(attrs)
+
+
+if hasattr(six, "ensure_binary"):
+    ensure_binary = six.ensure_binary
+else:
+    # For older versions of six (<1.12), fallback to local
+    # implementation
+
+    def ensure_binary(s, encoding='utf-8', errors='strict'):
+        """Coerce **s** to six.binary_type.
+        For Python 2:
+          - `unicode` -> encoded to `str`
+          - `str` -> `str`
+        For Python 3:
+          - `str` -> encoded to `bytes`
+          - `bytes` -> `bytes`
+
+        Code taken from https://github.com/benjaminp/six/blob/1.12.0/six.py#L853
+        """
+        if isinstance(s, six.text_type):
+            return s.encode(encoding, errors)
+        elif isinstance(s, six.binary_type):
+            return s
+        else:
+            raise TypeError("not expecting type '%s'" % type(s))
+
+
+class PyTangoHelpFormatter(HelpFormatter):
+
+    def _format_usage(self, usage, actions, groups, prefix):
+        usage = super(PyTangoHelpFormatter, self)._format_usage(usage, actions, groups, prefix)
+        try:
+            db = Database()
+            servers_list = db.get_instance_name_list(self._prog)
+            if servers_list.size():
+                usage += 'Instance names defined in database for server {}:\n'.format(self._prog)
+                for server in servers_list:
+                    usage += '\t' + str(server) + '\n'
+            else:
+                usage += 'Warning! No defined instance in database for server {} found!\n'.format(self._prog)
+        except DevFailed:
+            pass
+
+        return usage
\ No newline at end of file
