@@ -4,11 +4,14 @@
 import time
 import socket
 from functools import partial
+from threading import Thread
 
 import pytest
 from six import StringIO
 
-from tango import EventType, GreenMode, DeviceProxy, AttrQuality
+from tango import (
+    EventType, GreenMode, DeviceProxy, AttrQuality, EnsureOmniThread, is_omni_thread,
+)
 from tango.server import Device
 from tango.server import command, attribute
 from tango.test_utils import DeviceTestContext
@@ -42,17 +45,22 @@ class EventDevice(Device):
 
     def init_device(self):
         self.set_change_event("attr", True, False)
+        self.set_data_ready_event('attr', True)
 
     @attribute
     def attr(self):
         return 0.
 
     @command
-    def send_event(self):
+    def send_change_event(self):
         self.push_change_event("attr", 1.)
 
     @command
-    def send_event_with_timestamp(self):
+    def send_data_ready_event(self):
+        self.push_data_ready_event("attr", 2)
+
+    @command
+    def send_change_event_with_timestamp(self):
         self.push_change_event("attr", 2., 3., AttrQuality.ATTR_WARNING)
 
     @command(dtype_in=str)
@@ -90,28 +98,54 @@ def event_device(request):
 # Tests
 
 def test_subscribe_change_event(event_device):
-    results = []
+    results_change_event = []
 
-    def callback(evt):
-        results.append(evt.attr_value.value)
+    def callback_change(evt):
+        results_change_event.append(evt.attr_value.value)
+
+    # Subscribe to change event
+    eid_change = event_device.subscribe_event(
+        "attr", EventType.CHANGE_EVENT, callback_change, wait=True)
+    assert eid_change == 1
 
-    # Subscribe
-    eid = event_device.subscribe_event(
-        "attr", EventType.CHANGE_EVENT, callback, wait=True)
-    assert eid == 1
     # Trigger an event
-    event_device.command_inout("send_event", wait=True)
+    event_device.command_inout("send_change_event", wait=True)
     # Wait for tango event
     retries = 20
     for _ in range(retries):
         event_device.read_attribute("state", wait=True)
-        if len(results) > 1:
+        if len(results_change_event) > 1:
             break
         time.sleep(0.05)
     # Test the event values
-    assert results == [0., 1.]
+    assert results_change_event == [0., 1.]
     # Unsubscribe
-    event_device.unsubscribe_event(eid)
+    event_device.unsubscribe_event(eid_change)
+
+
+def test_subscribe_data_ready_event(event_device):
+    results_data_ready_event = []
+
+    def callback_data_ready(evt):
+        results_data_ready_event.append(evt.ctr)
+
+    # Subscribe to data ready event
+    eid_data_ready = event_device.subscribe_event(
+        "attr", EventType.DATA_READY_EVENT, callback_data_ready, wait=True)
+    assert eid_data_ready == 1
+    # Trigger an event
+    event_device.command_inout("send_data_ready_event", wait=True)
+    # Wait for tango event
+    retries = 20
+    for _ in range(retries):
+        event_device.read_attribute("state", wait=True)
+        if len(results_data_ready_event):
+            break
+        time.sleep(0.05)
+    # Test the event values
+    assert results_data_ready_event == [2]
+    # Unsubscribe
+    event_device.unsubscribe_event(eid_data_ready)
 
 
 def test_subscribe_interface_event(event_device):
@@ -146,21 +180,21 @@ def test_subscribe_interface_event(event_device):
     assert set(cmd.cmd_name for cmd in results[0].cmd_list) == \
         {'Init', 'State', 'Status',
          'add_dyn_attr', 'delete_dyn_attr',
-         'send_event', 'send_event_with_timestamp'}
+         'send_change_event', 'send_data_ready_event', 'send_change_event_with_timestamp'}
     assert set(att.name for att in results[0].att_list) == \
         {'attr', 'State', 'Status'}
     # Test the second event value
     assert set(cmd.cmd_name for cmd in results[1].cmd_list) == \
         {'Init', 'State', 'Status',
          'add_dyn_attr', 'delete_dyn_attr',
-         'send_event', 'send_event_with_timestamp'}
+         'send_change_event', 'send_data_ready_event', 'send_change_event_with_timestamp'}
     assert set(att.name for att in results[1].att_list) == \
         {'attr', 'State', 'Status', 'bla'}
     # Test the third event value
     assert set(cmd.cmd_name for cmd in results[2].cmd_list) == \
         {'Init', 'State', 'Status',
          'add_dyn_attr', 'delete_dyn_attr',
-         'send_event', 'send_event_with_timestamp'}
+         'send_change_event', 'send_data_ready_event', 'send_change_event_with_timestamp'}
     assert set(att.name for att in results[2].att_list) == \
         {'attr', 'State', 'Status'}
     # Unsubscribe
@@ -175,7 +209,7 @@ def test_push_event_with_timestamp(event_device):
         "attr", EventType.CHANGE_EVENT, ec, wait=True)
     assert eid == 1
     # Trigger an event
-    event_device.command_inout("send_event_with_timestamp", wait=True)
+    event_device.command_inout("send_change_event_with_timestamp", wait=True)
     # Wait for tango event
     retries = 20
     for _ in range(retries):
@@ -194,3 +228,75 @@ def test_push_event_with_timestamp(event_device):
     assert line2 in string.getvalue()
     # Unsubscribe
     event_device.unsubscribe_event(eid)
+
+
+def test_main_thread_is_omni_thread():
+    assert is_omni_thread()
+
+
+def test_ensure_omni_thread_main_thread_is_omni_thread():
+    with EnsureOmniThread():
+        assert is_omni_thread()
+
+
+def test_user_thread_is_not_omni_thread():
+    thread_is_omni = dict(result=None)  # use a dict so thread can modify it
+
+    def thread_func():
+        thread_is_omni['result'] = is_omni_thread()
+
+    thread = Thread(target=thread_func)
+    thread.start()
+    thread.join()
+    assert thread_is_omni['result'] is False
+
+
+def test_ensure_omni_thread_user_thread_is_omni_thread():
+    thread_is_omni = dict(result=None)  # use a dict so thread can modify it
+
+    def thread_func():
+        with EnsureOmniThread():
+            thread_is_omni['result'] = is_omni_thread()
+
+    thread = Thread(target=thread_func)
+    thread.start()
+    thread.join()
+    assert thread_is_omni['result'] is True
+
+
+def test_subscribe_change_event_from_user_thread(event_device):
+    results = []
+
+    def callback(evt):
+        results.append(evt.attr_value.value)
+
+    def thread_func():
+        with EnsureOmniThread():
+            eid = event_device.subscribe_event(
+                "attr", EventType.CHANGE_EVENT, callback, wait=True)
+            while running:
+                time.sleep(0.05)
+            event_device.unsubscribe_event(eid)
+
+    # Start the thread
+    thread = Thread(target=thread_func)
+    running = True
+    thread.start()
+    # Wait for tango events
+    retries = 20
+    for _ in range(retries):
+        event_device.read_attribute("state", wait=True)
+        if len(results) == 1:
+            # Trigger an event (1 result means thread has completed subscription,
+            # as that results in an initial callback)
+            event_device.command_inout("send_change_event", wait=True)
+        elif len(results) > 1:
+            # At least 2 events means an event was received after subscription
+            break
+        time.sleep(0.05)
+    # Stop the thread
+    running = False
+    thread.join()
+    # Test the event values
+    assert results == [0., 1.]
+
